@@ -1,7 +1,4 @@
 """Python wrapper for getting air quality data from GIOS."""
-
-from __future__ import annotations
-
 import logging
 from contextlib import suppress
 from http import HTTPStatus
@@ -17,11 +14,14 @@ from .const import (
     ATTR_INDEX_LEVEL,
     ATTR_NAME,
     ATTR_VALUE,
+    POLLUTANT_MAP,
+    STATE_MAP,
     URL_INDEXES,
     URL_SENSOR,
     URL_STATION,
     URL_STATIONS,
 )
+from .exceptions import ApiError, InvalidSensorsData, NoStationError
 from .model import GiosSensors
 
 _LOGGER: Final = logging.getLogger(__name__)
@@ -40,6 +40,8 @@ class Gios:
 
         self.session = session
 
+        _LOGGER.info("Initializing GIOS for station ID: %s", self.station_id)
+
     async def async_update(self) -> GiosSensors:
         """Update GIOS data."""
         data: dict[str, dict[str, Any]] = {}
@@ -67,7 +69,7 @@ class Gios:
         for sensor_dict in self._station_data:
             data[sensor_dict["param"]["paramCode"].lower()] = {
                 ATTR_ID: sensor_dict[ATTR_ID],
-                ATTR_NAME: sensor_dict["param"]["paramName"],
+                ATTR_NAME: POLLUTANT_MAP[sensor_dict["param"]["paramName"]],
             }
 
         sensors = await self._get_all_sensors(data)
@@ -98,19 +100,22 @@ class Gios:
         for sensor, sensor_data in data.items():
             with suppress(IndexError, KeyError, TypeError):
                 index_level = ATTR_INDEX_LEVEL.format(sensor.lower().replace(".", ""))
-                sensor_data[ATTR_INDEX] = indexes[index_level]["indexLevelName"].lower()
+                sensor_data[ATTR_INDEX] = STATE_MAP[
+                    indexes[index_level]["indexLevelName"]
+                ]
 
         with suppress(IndexError, KeyError, TypeError):
             if indexes["stIndexLevel"]["indexLevelName"]:
                 data[ATTR_AQI.lower()] = {ATTR_NAME: ATTR_AQI}
-                data[ATTR_AQI.lower()][ATTR_VALUE] = indexes["stIndexLevel"][
-                    "indexLevelName"
-                ].lower()
+                data[ATTR_AQI.lower()][ATTR_VALUE] = STATE_MAP[
+                    indexes["stIndexLevel"]["indexLevelName"]
+                ]
 
         if data.get("pm2.5"):
             data["pm25"] = data.pop("pm2.5")
 
-        return from_dict(data_class=GiosSensors, data=data)
+        result: GiosSensors = from_dict(data_class=GiosSensors, data=data)
+        return result
 
     async def _get_stations(self) -> Any:
         """Retrieve list of measuring stations."""
@@ -148,30 +153,3 @@ class Gios:
                 raise ApiError(str(resp.status))
             data = await resp.json()
         return data
-
-
-class ApiError(Exception):
-    """Raised when GIOS API request ended in error."""
-
-    def __init__(self, status: str) -> None:
-        """Initialize."""
-        super().__init__(status)
-        self.status = status
-
-
-class InvalidSensorsData(Exception):
-    """Raised when sensors data is invalid."""
-
-    def __init__(self, status: str) -> None:
-        """Initialize."""
-        super().__init__(status)
-        self.status = status
-
-
-class NoStationError(Exception):
-    """Raised when no measuring station error."""
-
-    def __init__(self, status: str) -> None:
-        """Initialize."""
-        super().__init__(status)
-        self.status = status
